#!/usr/bin/ruby
=begin
= gfdnavi-thumb

Gfdnavi を用いた解析・図集出力を支援するスクリプト.
dcmodel-thumb (http://www.gfd-dennou.org/library/dcmodel/doc/dcmodel-tools/dcmodel-thum-sample/) を意識した.

本スクリプトから設定ファイルを読み込み,
Ruby スクリプトを生成することで,
陽にスクリプトを書かなくてもよいようになる.
そのためには解析・可視化に関するメソッドを
外部ファイルに蓄積しておき, そこから呼び出すことになる.

== Usage

ヘルプを参照:

  $ ruby $0 -h

== History

* 2011/03/07 納多 哲史   作成

== ToDo

* 解析や描画の引数が一個でない場合への対応
* 複数の解析用メソッドを組み合わせられるようにする
* 引数でファイルを指定できるようにする
* 各種メッセージ出力, エラー処理

=end

require 'csv'

# 描画内容を描いた CSV ファイル
conf = "test.conf"

# データのあるディレクトリ. ファイルの場所はここからの相対パスとして記述
data_home="http://0.0.0.0:3000/data/samples/reanalysis/ncep"
#data_home="http://0.0.0.0:3000/data/samples/jmadata/MSM-P/2006"

# 知見情報ファイルの場所
url = "http://127.0.0.1:3000/data/usr/root/test/test5.knlge"

# 解析・描画用メソッド
require_ana  = [
                "test_anaconf.rb"
               ]
require_view = [
                "test_viewconf.rb"
               ]

outfn = File.basename($0, ".rb") + "-make.rb"

title = "Test page 5"   # ページタイトル
user = "root" # Gfdnaviサーバー上のユーザ名
category = "test"
description = "test"
textbody =<<EOF
This is test page.
EOF
horizontal_figures = 3  # 一行に何枚の図を並べるかを指定
creator = "Satoshi Noda"

# --------------------------------------------------

def help
  print <<EOM
  Usage: ruby $0 [Option]

以下のファイルを準備する
* 設定ファイル
* 解析用・描画用メソッドを記入したファイル (option)

本スクリプト内のパラメータを設定する.
以下のコマンドでで実行される.

  $ ruby $0

デフォルトでは File.basename($0, ".rb") + "-make.rb" という名前の
ファイルが生成される.
それを実行すると Gfdnavi にて解析・可視化が行われる.

Option:

  -h: このページを表示.
EOM
  exit 0
end

def add_require(f, ary)
  if ary.size > 0 then
    ary.each{|s|
      f.puts "require " + "\'" + s + "\'"
    }
  end
end


if ARGV[0] == "-h" then
  help
end


f = open(outfn, "w")

# header
  f.print <<EOM
#!/usr/bin/ruby
require 'numru/gfdnavi_data'
EOM

add_require(f, require_ana)
add_require(f, require_view)

  f.print <<EOM
include NumRu

EOM

  f.print <<EOM
k = GfdnaviData::KnowledgeRemote.new # 遠隔操作により知見情報を作成
k.url = "#{url}" # 保存先を指定
k.title = "#{title}"
k.user = "#{user}"
k.category = "#{category}"
k.description = "#{description}"
k.textbody = "#{textbody}"
k.horizontal_figures = #{horizontal_figures}
k.creator = "#{creator}"

EOM

# main
i = 0
CSV.open(conf, 'r') do |row|

  # debug
#    p row
#    p i

  # コメントを飛ばす (注意: 本来 csv にコメント文はないはず)
  next if /^#/ =~ row[0]
  next if row[0] == nil

  if row.size == 5

    row.map{|s| s.strip!}

    fname = row[0]   # 例: T.jan.nc
    vname = row[1]   # 例: T
    method_ana = row[2]   # 例: 帯状平均温度
    method_view = row[3]
    caption = row[4]

    var = File.join(data_home, fname, vname)

    f.print <<EOM
var = "#{var}"
caption = "#{caption}"
data = GfdnaviData.open(var)
data_t = #{method_ana}(data)
plot = #{method_view}(data_t)
k.add_figure(plot, caption)

EOM

  else
    raise("ERROR: illegal row \(#{row}\).")
  end

  i=i+1
end

#puts "#{i} figures."
puts "#{outfn} is generated."
puts "Run \"ruby #{outfn}\""


# footer
  f.print <<EOM
k.save
EOM

f.close
